@@ -1,6 +1,6 @@
 use criterion::{black_box, criterion_group, criterion_main, Criterion};
-use rdst::bench_utils::{bench_common, bench_medley};
-use rdst::test_utils::NumericTest;
+use rdst::utils::bench_utils::{bench_common, bench_medley};
+use rdst::utils::test_utils::NumericTest;
 use rdst::RadixSort;
 use voracious_radix_sort::{RadixKey as VorKey, RadixSort as Vor, Radixable};
 
@@ -17,9 +17,9 @@ where
             }),
         ),
         (
-            "rdst_in_place",
+            "rdst_low_mem",
             Box::new(|mut input| {
-                input.radix_sort_in_place_unstable();
+                input.radix_sort_builder().with_low_mem_tuner().sort();
                 black_box(input);
             }),
         ),
@@ -48,9 +48,9 @@ where
             }),
         ),
         (
-            "rdst_in_place",
+            "rdst_low_mem",
             Box::new(|mut input| {
-                input.radix_sort_in_place_unstable();
+                input.radix_sort_builder().with_low_mem_tuner().sort();
                 black_box(input);
             }),
         ),
@@ -66,7 +66,6 @@ where
     bench_medley(c, &("full_sort_medley_".to_owned() + suffix), tests, shift);
 }
 
-
 fn full_sort_u32(c: &mut Criterion) {
     full_sort_common(c, 0u32, "u32");
 }
